;; Red Hat Linux default .emacs initialization file

;; Set up the keyboard so the delete key on both the regular keyboard
;; and the keypad delete the character under the cursor and to the right
;; under X, instead of the default, backspace behavior.
(global-set-key [delete] 'delete-char)
(global-set-key [kp-delete] 'delete-char)

(setq search-delete-char 8);  ctl-h is backspace in search-mode too

(define-key minibuffer-local-completion-map " " 'minibuffer-complete)

(setq inhibit-startup-message t
      default-major-mode 'text-mode
      require-final-newline t
      next-line-add-newlines nil
      mouse-yank-at-point t)


(set-default-font "-Adobe-Courier-Medium-R-Normal--14-140-75-75-M-90-ISO8859-1")

(setq term-setup-hook
    '(lambda ()
        (setq keyboard-translate-table "\C-@\C-a\C-b\C-c\C-d\C-e\C-f\C-g\C-?")
        (global-set-key "\M-h" 'help-for-help)))

(setq auto-mode-alist
      (append (list (cons "\\.pj$" 'java-mode))
              auto-mode-alist))

(setq load-path (cons "/usr/share/emacs/site-lisp/" load-path))
(setq load-path (cons "/home/bts/emacs/" load-path))
(setq load-path (cons (expand-file-name "~/elisp") load-path))
(add-hook 'text-mode-hook 'turn-on-auto-fill)
(add-hook 'message-mode-hook 'turn-on-auto-fill)
(add-hook 'mail-mode-hook 'turn-on-auto-fill)

(setq display-time-day-and-date t)
(display-time)
(require 'env)
(require 'disp-table)
(resize-minibuffer-mode)
(require 'uniquify)
; filladapt for really nice filling
(require 'filladapt)
(setq paren-mode 'paren)

(load-library "mailcrypt")
(mc-setversion "gpg")
(setq mc-passwd-timeout 3600)
(global-font-lock-mode t)

; Turn on Wheel Mouse
(setq imwheel-scroll-interval 3)
(defun imwheel-scroll-down-some-lines ()
  (interactive)
  (scroll-down imwheel-scroll-interval))
(defun imwheel-scroll-up-some-lines ()
  (interactive)
  (scroll-up imwheel-scroll-interval))
(global-set-key [?\M-\C-\)] 'imwheel-scroll-up-some-lines)
(global-set-key [?\M-\C-\(] 'imwheel-scroll-down-some-lines)


; AucTeX
; done automatically on all my machines.
;(load "tex-site")

; Turn on bbdb
(require 'bbdb)
(bbdb-initialize 'gnus 'message 'w3)
;(add-hook 'gnus-startup-hook 'bbdb-insinuate-gnus)
;(add-hook 'gnus-startup-hook 'bbdb-insinuate-message)
;(setq rmail-mode-hook 'bbdb-insinuate-rmail)
;(setq mh-folder-mode-hook 'bbdb-insinuate-mh)
;(add-hook  'mail-setup-hook 'bbdb-insinuate-sendmail)
;(add-hook 'mail-setup-hook 'bbdb-define-all-aliases)
;(add-hook 'message-mode-hook '(lambda () (local-set-key [A-TAB] 'bbdb-complete-name)))
;(add-hook 'message-mode-hook '(lambda () (local-set-key [M-TAB] 'bbdb-complete-name)))
;(add-hook 'message-mode-hook '(lambda () (local-set-key [ESC TAB] 'bbdb-complete-name)))

; I live in Boston
(setq bbdb-default-area-code 617)
(setq bbdb-default-local-prefix 9)

; Turn on mailcrypt
(autoload 'mc-install-write-mode "mailcrypt" nil t)
(autoload 'mc-install-read-mode "mailcrypt" nil t)
(autoload 'mc-sign-region "mc-toplev" nil t)

(add-hook 'mail-mode-hook 'mc-install-write-mode)

(add-hook 'gnus-summary-mode-hook 'mc-install-read-mode)
(add-hook 'message-mode-hook 'mc-install-write-mode)
(add-hook 'news-reply-mode-hook 'mc-install-write-mode)
(add-hook 'message-setup-hook 'flyspell-mode)

; Turn on autocreation of bbdb records when in "inbox" 
; (or other useful groups).
(add-hook 'gnus-select-group-hook
	  '(lambda ()
	     (setq bbdb/news-auto-create-p
		   (or (string= "nnimap+smtp.smtp.evenmere.org:INBOX.personal" gnus-newsgroup-name)
		       (string= "nnimap+smtp.smtp.evenmere.org:INBOX.games-shadowdawn" gnus-newsgroup-name)
		       (string= "nnimap+smtp.smtp.evenmere.org:INBOX.lists-evenmere" gnus-newsgroup-name)))))

; I've moved from brians to bts; nevertheless, I should recognize either.
(setq bbdb-user-mail-names "(bts)|(brians)")

; Flag known posters in Gnus.  Turned off since I use it mostly for mail.
;(autoload 'bbdb/gnus-lines-and-from "bbdb-gnus")
;(setq gnus-optional-headers 'bbdb/gnus-lines-and-from)

; Turn bts@grecotha.kendall.akamai.com into bts@akamai.com after seeing both.
(setq bbdb-canonicalize-redundant-nets-p 't)

;; Supercite stuff
(add-hook 'mail-citation-hook 'sc-cite-original) 
(setq sc-auto-fill-region-p nil)
(setq sc-preferred-attribution-list
      '("x-attribution" "initials"))
(setq sc-citation-leader "")
(setq sc-blank-lines-after-headers 0)


;;; postscript mode
;; Set up autoloading and auto-mode
(autoload 'ps-mode "ps-mode"
  "Major mode for editing PostScript" t)
(setq auto-mode-alist
      (append
       '(("\\.[eE]?[pP][sS]$" . ps-mode))
       auto-mode-alist))

;; Turn on font lock, use lazy-lock for large PostScript files
(setq font-lock-maximum-decoration t)
(add-hook 'ps-mode-hook
	  '(lambda ()
	     (make-local-variable 'font-lock-support-mode)
	     (make-local-variable 'lazy-lock-defer-on-scrolling)
	     (setq font-lock-support-mode 'lazy-lock-mode
		   lazy-lock-defer-on-scrolling t)
	     (turn-on-font-lock)))
(add-hook 'ps-run-mode-hook
	  '(lambda ()
	     (turn-on-font-lock)))


(put 'downcase-region 'disabled nil)
(custom-set-variables
  ;; custom-set-variables was added by Custom -- don't edit or cut/paste it!
  ;; Your init file should contain only one such instance.
 '(ange-ftp-try-passive-mode t)
 '(bbdb-complete-name-allow-cycling t)
 '(bbdb-complete-name-hooks t)
 '(bbdb-completion-type (quote primary-or-name))
 '(bbdb-display-layout (quote multi-line))
 '(bbdb-electric-p t)
 '(bbdb-offer-save (quote savenoprompt))
 '(bbdb-pop-up-display-layout (quote one-line))
 '(bbdb-send-mail-style (quote message))
 '(bbdb-use-pop-up t)
 '(bbdb/gnus-update-records-mode (quote annotating))
 '(blink-cursor nil)
 '(browse-url-browser-function (quote browse-url-generic))
 '(browse-url-generic-program "opera")
 '(canlock-password "991144d663f37c5f2813e100c3323fbb6823f32f")
 '(gnus-agent t)
 '(gnus-boring-article-headers (quote (empty followup-to reply-to long-to)))
 '(gnus-cite-always-check t)
 '(gnus-save-score t)
 '(gnus-score-thread-simplify t)
 '(gnus-show-all-headers nil)
 '(gnus-summary-ignore-duplicates t)
 '(gnus-treat-from-picon nil)
 '(gnus-treat-mail-picon nil)
 '(gnus-treat-newsgroups-picon nil)
 '(gnus-treat-strip-pgp nil)
 '(gnus-treat-x-pgp-sig (quote head))
 '(gnuserv-program "/usr/bin/gnuserv")
 '(gpg-passphrase-timeout 14400)
 '(load-home-init-file t t)
 '(menu-bar-mode nil)
 '(message-cite-function (quote message-cite-original-without-signature))
 '(mm-verify-option (quote known))
 '(nnimap-dont-close nil)
 '(tool-bar-mode nil nil (tool-bar))
 '(user-mail-address "bts@alum.mit.edu"))

;;; Emacs/W3 Configuration
;(require 'w3-auto)
(custom-set-faces
  ;; custom-set-faces was added by Custom -- don't edit or cut/paste it!
  ;; Your init file should contain only one such instance.
 )
(setq url-proxy-services
      '(("http" . "localhost:3128")))

; choose-color (cooler font lock mode)
;(eval-after-load "font-lock" '(require 'choose-color))
;(autoload 'choose-color "choose-color" "Choose color wisely.")


; CPerl mode
(autoload 'perl-mode "cperl-mode" "alternate mode for editing Perl programs" t)
(setq cperl-hairy t)
(setq cperl-indent-level 4)
(setq auto-mode-alist
      (append '(("\\.\\([pP][Llm]\\|al\\)$" . perl-mode))  auto-mode-alist ))
;(define-key global-map [M-S-down-mouse-3] 'imenu)

; ZWiki Integration
;; For editing Zope ZWikis
;; To treat certain files automatically as ZWiki pages:
(push
 (cons (concat "/bts@10.0.0.77#8021:/"
	       ".*/\\(\\b[A-Z]+[a-z]+[A-Z][A-Za-z]*[0-9]*\\|"
	       "\\b[A-Z][A-Z]+[a-z][A-Za-z]*[0-9]*\\)$")
       'zwiki-mode)
 auto-mode-alist)

(autoload 'zwiki-mode "zwiki-mode-plus"
  "Major mode for editing a zwiki page via ftp." t)
(autoload 'zwiki-edit-via-ftp "zwiki-mode-plus"
  "Find the FTP file corresponding to the HTTP URL" t)

;; ZWiki is so good I am going to give it a global binding:
;(global-set-key '[(control c) z] 'zwiki-edit-via-ftp)

; Perforce
;(load-library "p4")
;(autoload 'p4-merge-mode "p4-merge" nil t)
;(setq p4-merge-style 'ediff) 
;(p4-set-p4-executable "/usr/local/bin/p4")

; Babelfish Glue
;(require 'babel)

; Pilot Glue
;(require 'bbdb-pilot-jwz)
;(load-library "pilot-memo")

; Emacs-IRC glue
;(require 'erc)

;;; uniquify (require 'uniquify)
(setq uniquify-buffer-name-style
      'post-forward-angle-brackets)


(put 'narrow-to-region 'disabled nil)

(defun alist-add-replace (alist values)
  "Add or replace in the alist variable ALIST entries VALUES."
  (mapc (lambda (x)
	  (let ((place (assoc (car x) (symbol-value alist))))
	    (if place
		(setcdr place (cdr x))
	      (set alist (cons x (symbol-value alist))))))
	values))

(alist-add-replace
 'default-frame-alist
 `((width . 125)
   (height . 55)
   (foreground-color . "white")
   (background-color . "black")
   (mouse-color . "white")
   (cursor-color . "white")
   (background-mode . dark)
   ;; No tool bars please.
   (tool-bar-lines . nil)
   ,@(if window-system nil '((menu-bar-lines . nil)))))

